pub enum InternalAddress {
Show 15 variants
PoS,
PosSlashPool,
Parameters,
Ibc,
IbcToken(IbcTokenHash),
Governance,
EthBridge,
EthBridgePool,
Erc20(EthAddress),
Nut(EthAddress),
Multitoken,
Pgf,
Masp,
ReplayProtection,
TempStorage,
}Expand description
An internal address represents a module with a native VP
Variants
PoS
Proof-of-stake
PosSlashPool
Proof-of-stake slash pool contains slashed tokens
Parameters
Protocol parameters
Ibc
Inter-blockchain communication
IbcToken(IbcTokenHash)
IBC-related token
Governance
Governance address
EthBridge
Bridge to Ethereum
EthBridgePool
The pool of transactions to be relayed to Ethereum
Erc20(EthAddress)
ERC20 token for Ethereum bridge
Nut(EthAddress)
Non-usable ERC20 tokens
Multitoken
Multitoken
Pgf
Pgf
Masp
Masp
ReplayProtection
Replay protection
TempStorage
Address with temporary storage is used to pass data from txs to VPs which is never committed to DB
Implementations
Sourceimpl InternalAddress
impl InternalAddress
Sourcepub fn try_from_alias(alias: &str) -> Option<InternalAddress>
pub fn try_from_alias(alias: &str) -> Option<InternalAddress>
Certain internal addresses have reserved aliases.