pub enum ResultCode {
Show 13 variants
Ok = 0,
WasmRuntimeError = 1,
InvalidTx = 2,
InvalidSig = 3,
AllocationError = 4,
ReplayTx = 5,
InvalidChainId = 6,
ExpiredTx = 7,
TxGasLimit = 8,
FeeError = 9,
InvalidVoteExtension = 10,
TooLarge = 11,
TxNotAllowlisted = 12,
}Expand description
The different result codes that the ledger may send back to a client indicating the status of their submitted tx. The codes must not change with versions, only need ones may be added.
Variants
Ok = 0
Success
WasmRuntimeError = 1
Error in WASM tx execution
InvalidTx = 2
Invalid tx
InvalidSig = 3
Invalid signature
AllocationError = 4
The block is full
ReplayTx = 5
Replayed tx
InvalidChainId = 6
Invalid chain ID
ExpiredTx = 7
Expired tx
TxGasLimit = 8
Exceeded gas limit
FeeError = 9
Error in paying tx fee
InvalidVoteExtension = 10
Invalid vote extension
TooLarge = 11
Tx is too large
TxNotAllowlisted = 12
Tx code is not allowlisted
Implementations
Sourceimpl ResultCode
impl ResultCode
Sourcepub const fn is_recoverable(&self) -> bool
pub const fn is_recoverable(&self) -> bool
Checks if the given ResultCode value is a protocol level error,
that can be recovered from at the finalize block stage.
Sourcepub fn from_u32(raw: u32) -> Option<ResultCode>
pub fn from_u32(raw: u32) -> Option<ResultCode>
Convert from u32.