pub struct Header {
pub chain_id: ChainId,
pub expiration: Option<DateTimeUtc>,
pub timestamp: DateTimeUtc,
pub batch: IndexSet<TxCommitments>,
pub atomic: bool,
pub tx_type: TxType,
}Expand description
A Namada transaction header indicating where transaction subcomponents can be found
Fields
chain_id: ChainIdThe chain which this transaction is being submitted to
expiration: Option<DateTimeUtc>The time at which this transaction expires
timestamp: DateTimeUtcA transaction timestamp
batch: IndexSet<TxCommitments>The commitments to the transaction’s sections
atomic: boolWhether the inner txs should be executed atomically
tx_type: TxTypeThe type of this transaction
Implementations
Sourceimpl Header
impl Header
Sourcepub fn hash<'a>(
&self,
hasher: &'a mut CoreWrapper<CtVariableCoreWrapper<Sha256VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>, OidSha256>>,
) -> &'a mut CoreWrapper<CtVariableCoreWrapper<Sha256VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>, OidSha256>> ⓘ
pub fn hash<'a>( &self, hasher: &'a mut CoreWrapper<CtVariableCoreWrapper<Sha256VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>, OidSha256>>, ) -> &'a mut CoreWrapper<CtVariableCoreWrapper<Sha256VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>, OidSha256>> ⓘ
Get the hash of this transaction header.
Sourcepub fn protocol(&self) -> Option<ProtocolTx>
pub fn protocol(&self) -> Option<ProtocolTx>
Get the protocol header if it is present