pub struct Shell { /* private fields */ }Expand description
Shellpath router type
Implementations
Sourceimpl Shell
impl Shell
Sourcepub const fn sub(prefix: String) -> Self
pub const fn sub(prefix: String) -> Self
Construct this router as a sub-router at the given prefix path
Sourcepub fn max_block_time_path(&self) -> String
pub fn max_block_time_path(&self) -> String
Get a path to query max_block_time.
Sourcepub async fn max_block_time<CLIENT>(
&self,
client: &CLIENT,
) -> Result<DurationSecs, <CLIENT as Client>::Error>
pub async fn max_block_time<CLIENT>( &self, client: &CLIENT, ) -> Result<DurationSecs, <CLIENT as Client>::Error>
Request a simple borsh-encoded value from max_block_time, without any additional request data, specified block height or proof.
Sourcepub fn block_header_path(&self, height: &BlockHeight) -> String
pub fn block_header_path(&self, height: &BlockHeight) -> String
Get a path to query block_header.
Sourcepub async fn block_header<CLIENT>(
&self,
client: &CLIENT,
height: &BlockHeight,
) -> Result<Option<BlockHeader>, <CLIENT as Client>::Error>
pub async fn block_header<CLIENT>( &self, client: &CLIENT, height: &BlockHeight, ) -> Result<Option<BlockHeader>, <CLIENT as Client>::Error>
Request a simple borsh-encoded value from block_header, without any additional request data, specified block height or proof.
Sourcepub fn ibc_packet_path(
&self,
event_type: &IbcEventType,
source_port: &PortId,
source_channel: &ChannelId,
destination_port: &PortId,
destination_channel: &ChannelId,
sequence: &Sequence,
) -> String
pub fn ibc_packet_path( &self, event_type: &IbcEventType, source_port: &PortId, source_channel: &ChannelId, destination_port: &PortId, destination_channel: &ChannelId, sequence: &Sequence, ) -> String
Get a path to query ibc_packet.
Sourcepub async fn ibc_packet<CLIENT>(
&self,
client: &CLIENT,
event_type: &IbcEventType,
source_port: &PortId,
source_channel: &ChannelId,
destination_port: &PortId,
destination_channel: &ChannelId,
sequence: &Sequence,
) -> Result<Option<Event>, <CLIENT as Client>::Error>
pub async fn ibc_packet<CLIENT>( &self, client: &CLIENT, event_type: &IbcEventType, source_port: &PortId, source_channel: &ChannelId, destination_port: &PortId, destination_channel: &ChannelId, sequence: &Sequence, ) -> Result<Option<Event>, <CLIENT as Client>::Error>
Request a simple borsh-encoded value from ibc_packet, without any additional request data, specified block height or proof.
Sourcepub fn ibc_client_update_path(
&self,
client_id: &ClientId,
consensus_height: &BlockHeight,
) -> String
pub fn ibc_client_update_path( &self, client_id: &ClientId, consensus_height: &BlockHeight, ) -> String
Get a path to query ibc_client_update.
Sourcepub async fn ibc_client_update<CLIENT>(
&self,
client: &CLIENT,
client_id: &ClientId,
consensus_height: &BlockHeight,
) -> Result<Option<Event>, <CLIENT as Client>::Error>
pub async fn ibc_client_update<CLIENT>( &self, client: &CLIENT, client_id: &ClientId, consensus_height: &BlockHeight, ) -> Result<Option<Event>, <CLIENT as Client>::Error>
Request a simple borsh-encoded value from ibc_client_update, without any additional request data, specified block height or proof.
Sourcepub fn revealed_path(&self, owner: &Address) -> String
pub fn revealed_path(&self, owner: &Address) -> String
Get a path to query revealed.
Sourcepub async fn revealed<CLIENT>(
&self,
client: &CLIENT,
owner: &Address,
) -> Result<bool, <CLIENT as Client>::Error>
pub async fn revealed<CLIENT>( &self, client: &CLIENT, owner: &Address, ) -> Result<bool, <CLIENT as Client>::Error>
Request a simple borsh-encoded value from revealed, without any additional request data, specified block height or proof.
Sourcepub fn account_path(&self, owner: &Address) -> String
pub fn account_path(&self, owner: &Address) -> String
Get a path to query account.
Sourcepub async fn account<CLIENT>(
&self,
client: &CLIENT,
owner: &Address,
) -> Result<Option<Account>, <CLIENT as Client>::Error>
pub async fn account<CLIENT>( &self, client: &CLIENT, owner: &Address, ) -> Result<Option<Account>, <CLIENT as Client>::Error>
Request a simple borsh-encoded value from account, without any additional request data, specified block height or proof.
Sourcepub fn applied_path(&self, tx_hash: &Hash) -> String
pub fn applied_path(&self, tx_hash: &Hash) -> String
Get a path to query applied.
Sourcepub async fn applied<CLIENT>(
&self,
client: &CLIENT,
tx_hash: &Hash,
) -> Result<Option<TxAppliedEvents>, <CLIENT as Client>::Error>
pub async fn applied<CLIENT>( &self, client: &CLIENT, tx_hash: &Hash, ) -> Result<Option<TxAppliedEvents>, <CLIENT as Client>::Error>
Request a simple borsh-encoded value from applied, without any additional request data, specified block height or proof.
Sourcepub fn read_results_path(&self) -> String
pub fn read_results_path(&self) -> String
Get a path to query read_results.
Sourcepub async fn read_results<CLIENT>(
&self,
client: &CLIENT,
) -> Result<Vec<BlockResults>, <CLIENT as Client>::Error>
pub async fn read_results<CLIENT>( &self, client: &CLIENT, ) -> Result<Vec<BlockResults>, <CLIENT as Client>::Error>
Request a simple borsh-encoded value from read_results, without any additional request data, specified block height or proof.
Sourcepub fn masp_reward_tokens_path(&self) -> String
pub fn masp_reward_tokens_path(&self) -> String
Get a path to query masp_reward_tokens.
Sourcepub async fn masp_reward_tokens<CLIENT>(
&self,
client: &CLIENT,
) -> Result<Vec<MaspTokenRewardData>, <CLIENT as Client>::Error>
pub async fn masp_reward_tokens<CLIENT>( &self, client: &CLIENT, ) -> Result<Vec<MaspTokenRewardData>, <CLIENT as Client>::Error>
Request a simple borsh-encoded value from masp_reward_tokens, without any additional request data, specified block height or proof.
Sourcepub fn read_conversions_path(&self, masp_epoch: &MaspEpoch) -> String
pub fn read_conversions_path(&self, masp_epoch: &MaspEpoch) -> String
Get a path to query read_conversions.
Sourcepub async fn read_conversions<CLIENT>(
&self,
client: &CLIENT,
masp_epoch: &MaspEpoch,
) -> Result<BTreeMap<AssetType, (Address, Denomination, MaspDigitPos, MaspEpoch, I128Sum)>, <CLIENT as Client>::Error>
pub async fn read_conversions<CLIENT>( &self, client: &CLIENT, masp_epoch: &MaspEpoch, ) -> Result<BTreeMap<AssetType, (Address, Denomination, MaspDigitPos, MaspEpoch, I128Sum)>, <CLIENT as Client>::Error>
Request a simple borsh-encoded value from read_conversions, without any additional request data, specified block height or proof.
Sourcepub fn read_conversion_path(&self, asset_type: &AssetType) -> String
pub fn read_conversion_path(&self, asset_type: &AssetType) -> String
Get a path to query read_conversion.
Sourcepub async fn read_conversion<CLIENT>(
&self,
client: &CLIENT,
asset_type: &AssetType,
) -> Result<Option<(Address, Denomination, MaspDigitPos, MaspEpoch, I128Sum, MerklePath<Node>)>, <CLIENT as Client>::Error>
pub async fn read_conversion<CLIENT>( &self, client: &CLIENT, asset_type: &AssetType, ) -> Result<Option<(Address, Denomination, MaspDigitPos, MaspEpoch, I128Sum, MerklePath<Node>)>, <CLIENT as Client>::Error>
Request a simple borsh-encoded value from read_conversion, without any additional request data, specified block height or proof.
Sourcepub fn storage_has_key_path(&self, storage_key: &Key) -> String
pub fn storage_has_key_path(&self, storage_key: &Key) -> String
Get a path to query storage_has_key.
Sourcepub async fn storage_has_key<CLIENT>(
&self,
client: &CLIENT,
storage_key: &Key,
) -> Result<bool, <CLIENT as Client>::Error>
pub async fn storage_has_key<CLIENT>( &self, client: &CLIENT, storage_key: &Key, ) -> Result<bool, <CLIENT as Client>::Error>
Request a simple borsh-encoded value from storage_has_key, without any additional request data, specified block height or proof.
Sourcepub fn storage_prefix_path(&self, storage_key: &Key) -> String
pub fn storage_prefix_path(&self, storage_key: &Key) -> String
Get a path to query storage_prefix.
Sourcepub async fn storage_prefix<CLIENT>(
&self,
client: &CLIENT,
data: Option<Vec<u8>>,
height: Option<BlockHeight>,
prove: bool,
storage_key: &Key,
) -> Result<ResponseQuery<Vec<PrefixValue>>, <CLIENT as Client>::Error>
pub async fn storage_prefix<CLIENT>( &self, client: &CLIENT, data: Option<Vec<u8>>, height: Option<BlockHeight>, prove: bool, storage_key: &Key, ) -> Result<ResponseQuery<Vec<PrefixValue>>, <CLIENT as Client>::Error>
Request value with optional data (used for e.g. dry_run_tx), optionally specified height (supported for storage_value) and optional proof (supported for storage_value and storage_prefix) from storage_prefix.
Sourcepub fn dry_run_tx_path(&self) -> String
pub fn dry_run_tx_path(&self) -> String
Get a path to query dry_run_tx.
Sourcepub async fn dry_run_tx<CLIENT>(
&self,
client: &CLIENT,
data: Option<Vec<u8>>,
height: Option<BlockHeight>,
prove: bool,
) -> Result<ResponseQuery<DryRunResult>, <CLIENT as Client>::Error>
pub async fn dry_run_tx<CLIENT>( &self, client: &CLIENT, data: Option<Vec<u8>>, height: Option<BlockHeight>, prove: bool, ) -> Result<ResponseQuery<DryRunResult>, <CLIENT as Client>::Error>
Request value with optional data (used for e.g. dry_run_tx), optionally specified height (supported for storage_value) and optional proof (supported for storage_value and storage_prefix) from dry_run_tx.
Sourcepub fn storage_value_path(&self, storage_key: &Key) -> String
pub fn storage_value_path(&self, storage_key: &Key) -> String
Get a path to query storage_value.
Sourcepub async fn storage_value<CLIENT>(
&self,
client: &CLIENT,
data: Option<Vec<u8>>,
height: Option<BlockHeight>,
prove: bool,
storage_key: &Key,
) -> Result<ResponseQuery<Vec<u8>>, <CLIENT as Client>::Error>
pub async fn storage_value<CLIENT>( &self, client: &CLIENT, data: Option<Vec<u8>>, height: Option<BlockHeight>, prove: bool, storage_key: &Key, ) -> Result<ResponseQuery<Vec<u8>>, <CLIENT as Client>::Error>
Request value with optional data (used for e.g. dry_run_tx), optionally specified height (supported for storage_value) and optional proof (supported for storage_value and storage_prefix) from storage_value.
Sourcepub fn first_block_height_of_current_epoch_path(&self) -> String
pub fn first_block_height_of_current_epoch_path(&self) -> String
Get a path to query first_block_height_of_current_epoch.
Sourcepub async fn first_block_height_of_current_epoch<CLIENT>(
&self,
client: &CLIENT,
) -> Result<BlockHeight, <CLIENT as Client>::Error>
pub async fn first_block_height_of_current_epoch<CLIENT>( &self, client: &CLIENT, ) -> Result<BlockHeight, <CLIENT as Client>::Error>
Request a simple borsh-encoded value from first_block_height_of_current_epoch, without any additional request data, specified block height or proof.
Sourcepub fn last_block_path(&self) -> String
pub fn last_block_path(&self) -> String
Get a path to query last_block.
Sourcepub async fn last_block<CLIENT>(
&self,
client: &CLIENT,
) -> Result<Option<LastBlock>, <CLIENT as Client>::Error>
pub async fn last_block<CLIENT>( &self, client: &CLIENT, ) -> Result<Option<LastBlock>, <CLIENT as Client>::Error>
Request a simple borsh-encoded value from last_block, without any additional request data, specified block height or proof.
Sourcepub fn epoch_at_height_path(&self, height: &BlockHeight) -> String
pub fn epoch_at_height_path(&self, height: &BlockHeight) -> String
Get a path to query epoch_at_height.
Sourcepub async fn epoch_at_height<CLIENT>(
&self,
client: &CLIENT,
height: &BlockHeight,
) -> Result<Option<Epoch>, <CLIENT as Client>::Error>
pub async fn epoch_at_height<CLIENT>( &self, client: &CLIENT, height: &BlockHeight, ) -> Result<Option<Epoch>, <CLIENT as Client>::Error>
Request a simple borsh-encoded value from epoch_at_height, without any additional request data, specified block height or proof.
Sourcepub fn native_token_path(&self) -> String
pub fn native_token_path(&self) -> String
Get a path to query native_token.
Sourcepub async fn native_token<CLIENT>(
&self,
client: &CLIENT,
) -> Result<Address, <CLIENT as Client>::Error>
pub async fn native_token<CLIENT>( &self, client: &CLIENT, ) -> Result<Address, <CLIENT as Client>::Error>
Request a simple borsh-encoded value from native_token, without any additional request data, specified block height or proof.
Sourcepub fn masp_epoch_path(&self) -> String
pub fn masp_epoch_path(&self) -> String
Get a path to query masp_epoch.
Sourcepub async fn masp_epoch<CLIENT>(
&self,
client: &CLIENT,
) -> Result<MaspEpoch, <CLIENT as Client>::Error>
pub async fn masp_epoch<CLIENT>( &self, client: &CLIENT, ) -> Result<MaspEpoch, <CLIENT as Client>::Error>
Request a simple borsh-encoded value from masp_epoch, without any additional request data, specified block height or proof.
Sourcepub fn epoch_path(&self) -> String
pub fn epoch_path(&self) -> String
Get a path to query epoch.
Sourcepub async fn epoch<CLIENT>(
&self,
client: &CLIENT,
) -> Result<Epoch, <CLIENT as Client>::Error>
pub async fn epoch<CLIENT>( &self, client: &CLIENT, ) -> Result<Epoch, <CLIENT as Client>::Error>
Request a simple borsh-encoded value from epoch, without any additional request data, specified block height or proof.
Sourcepub fn eth_bridge(&self) -> EthBridge
pub fn eth_bridge(&self) -> EthBridge
Shell sub-router